summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/effects.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/effects.cc')
-rw-r--r--crawl-ref/source/effects.cc11
1 files changed, 5 insertions, 6 deletions
diff --git a/crawl-ref/source/effects.cc b/crawl-ref/source/effects.cc
index bae43a8677..b213683e5d 100644
--- a/crawl-ref/source/effects.cc
+++ b/crawl-ref/source/effects.cc
@@ -1045,7 +1045,7 @@ static int find_acquirement_subtype(object_class_type class_wanted,
case SK_EVOCATIONS:
if (!one_chance_in(4))
- type_wanted = STAFF_SMITING + random2(10);
+ type_wanted = random_rod_subtype();
break;
default: // invocations and leftover spell schools
@@ -1073,16 +1073,15 @@ static int find_acquirement_subtype(object_class_type class_wanted,
break;
}
// Increased chance of getting spell staff for new or
// non-spellcasters. -- bwr
if (one_chance_in(20)
|| (spell_skills <= 1 // short on spells
- && (type_wanted < STAFF_SMITING // already making one
- || type_wanted >= STAFF_AIR)
+ && type_wanted < STAFF_SMITING
&& !one_chance_in(4)))
{
- type_wanted = (coinflip() ? STAFF_STRIKING
- : STAFF_SMITING + random2(10));
+ type_wanted = coinflip() ? STAFF_STRIKING :
+ random_rod_subtype();
}
break;
@@ -1073,16 +1073,15 @@ static int find_acquirement_subtype(object_class_type class_wanted,
break;
}
- // Increased chance of getting spell staff for new or
+ // Increased chance of getting a rod for new or
// non-spellcasters. -- bwr
if (one_chance_in(20)